# @dynatrace-sdk/client-notification

[![npm](https://img.shields.io/badge/npm-v2.0.2-blue)](https://www.npmjs.com/package/@dynatrace-sdk/client-notification/v/2.0.2)
[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

Manage self notifications with the Notification Service API.


## Installation

```bash
npm install @dynatrace-sdk/client-notification
```


## Getting help

- Visit [SDK for Typescript](https://developer.dynatrace.com/reference/sdks/) guide in the [Dynatrace Developer](https://developer.dynatrace.com/)
- Ask a question in the [Dynatrace Community](https://community.dynatrace.com/)


## License

This SDK is distributed under the [Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0), see LICENSE for more information.


# API reference

Full API reference for the latest version of the SDK is also available at the [Dynatrace Developer](https://developer.dynatrace.com/reference/sdks/client-notification/).

## selfNotificationsClient

```js
import { selfNotificationsClient } from '@dynatrace-sdk/client-notification';
```


<a name="createselfnotification"></a>
### createSelfNotification

<div class="padding-bottom--md">
<strong>selfNotificationsClient.createSelfNotification(config): Promise&lt;<a href="#selfnotification">SelfNotification</a>&gt;</strong>

<div class="padding-left--md">

**Required scope:** notification:self-notifications:write



</div>


#### Parameters

| Name | Type |
| --- | --- |
|config.body<sup>*required</sup>|<a href="#selfnotificationcreate" target="_blank" rel="noopener noreferrer">SelfNotificationCreate</a>| 




#### Returns

| Return type | Status code | Description |
|---|---|---|
|[SelfNotification](#selfnotification)|201||


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError||


<details>
<summary>
Code example
</summary>

```ts
import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";

const data =
  await selfNotificationsClient.createSelfNotification({
    body: {
      resourceId: "...",
      notificationType: "...",
      triggerConfiguration: {
        type: EventQueryTriggerConfigType.Event,
        value: { query: "..." },
      },
    },
  });
```

</details>



</div>


<a name="deleteselfnotification"></a>
### deleteSelfNotification

<div class="padding-bottom--md">
<strong>selfNotificationsClient.deleteSelfNotification(config): Promise&lt;void&gt;</strong>

<div class="padding-left--md">

**Required scope:** notification:self-notifications:write



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|config.id<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|A UUID string identifying this self notification. |




#### Returns

| Return type | Status code | Description |
|---|---|---|
|void|204|No response body|


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError||


<details>
<summary>
Code example
</summary>

```ts
import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";

const data =
  await selfNotificationsClient.deleteSelfNotification({
    id: "...",
  });
```

</details>



</div>


<a name="getselfnotification"></a>
### getSelfNotification

<div class="padding-bottom--md">
<strong>selfNotificationsClient.getSelfNotification(config): Promise&lt;<a href="#selfnotification">SelfNotification</a>&gt;</strong>

<div class="padding-left--md">

**Required scope:** notification:self-notifications:read



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|config.id<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|A UUID string identifying this self notification. |




#### Returns

| Return type | Status code | Description |
|---|---|---|
|[SelfNotification](#selfnotification)|200||


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError||


<details>
<summary>
Code example
</summary>

```ts
import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";

const data =
  await selfNotificationsClient.getSelfNotification({
    id: "...",
  });
```

</details>



</div>


<a name="getselfnotifications"></a>
### getSelfNotifications

<div class="padding-bottom--md">
<strong>selfNotificationsClient.getSelfNotifications(config): Promise&lt;<a href="#paginatedselfnotificationlist" target="_blank" rel="noopener noreferrer">PaginatedSelfNotificationList</a>&gt;</strong>

<div class="padding-left--md">

**Required scope:** notification:self-notifications:read



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|config.appId|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| |
|config.limit|[number](https://developer.mozilla.org/en-US/docs/Glossary/Number)|Number of results to return per page. |
|config.notificationType|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| |
|config.offset|[number](https://developer.mozilla.org/en-US/docs/Glossary/Number)|The initial index from which to return the results. |
|config.ordering|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Which field to use when ordering the results. |
|config.owner|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| |
|config.resourceId|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| |
|config.search|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|A search term. |




#### Returns

| Return type | Status code | Description |
|---|---|---|
|[PaginatedSelfNotificationList](#paginatedselfnotificationlist)|200||


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError||


<details>
<summary>
Code example
</summary>

```ts
import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";

const data =
  await selfNotificationsClient.getSelfNotifications();
```

</details>



</div>


<a name="patchselfnotification"></a>
### patchSelfNotification

<div class="padding-bottom--md">
<strong>selfNotificationsClient.patchSelfNotification(config): Promise&lt;<a href="#selfnotification">SelfNotification</a>&gt;</strong>

<div class="padding-left--md">

**Required scope:** notification:self-notifications:write



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|config.body<sup>*required</sup>|<a href="#selfnotificationupdate" target="_blank" rel="noopener noreferrer">SelfNotificationUpdate</a>| |
|config.id<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|A UUID string identifying this self notification. |




#### Returns

| Return type | Status code | Description |
|---|---|---|
|[SelfNotification](#selfnotification)|200||


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError||


<details>
<summary>
Code example
</summary>

```ts
import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";

const data =
  await selfNotificationsClient.patchSelfNotification({
    id: "...",
    body: {
      triggerConfiguration: {
        type: EventQueryTriggerConfigType.Event,
        value: { query: "..." },
      },
    },
  });
```

</details>



</div>


<a name="updateselfnotification"></a>
### updateSelfNotification

<div class="padding-bottom--md">
<strong>selfNotificationsClient.updateSelfNotification(config): Promise&lt;<a href="#selfnotification">SelfNotification</a>&gt;</strong>

<div class="padding-left--md">

**Required scope:** notification:self-notifications:write



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|config.body<sup>*required</sup>|<a href="#selfnotificationupdate" target="_blank" rel="noopener noreferrer">SelfNotificationUpdate</a>| |
|config.id<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|A UUID string identifying this self notification. |




#### Returns

| Return type | Status code | Description |
|---|---|---|
|[SelfNotification](#selfnotification)|200||


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError||


<details>
<summary>
Code example
</summary>

```ts
import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";

const data =
  await selfNotificationsClient.updateSelfNotification({
    id: "...",
    body: {
      triggerConfiguration: {
        type: EventQueryTriggerConfigType.Event,
        value: { query: "..." },
      },
    },
  });
```

</details>



</div>

## Types

### DavisEventConfig

| Name | Type | Description |
| --- | --- | --- |
|customFilter|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Additional DQL matcher expression to further filter events to match. |
|entityTags|<a href="#entitytags">EntityTags</a>|Entity tags to match by key and (optional) values. For example &#123;&quot;foo&quot;: [], &quot;bar&quot;: [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]} |
|entityTagsMatch|"all" &#124; "any"|Event must match all or any of the entity tags. |
|names|Array&lt;<a href="#daviseventname" target="_blank" rel="noopener noreferrer">DavisEventName</a>&gt;| |
|onProblemClose|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)|Trigger on Davis event open only or also on close. <i>default:</i> <code>false</code>|
|~~types~~<sup>**DEPRECATED**</sup>|Array&lt;[string](https://developer.mozilla.org/en-US/docs/Glossary/String)&gt;| |

### DavisEventName

| Name | Type | Description |
| --- | --- | --- |
|match<sup>*required</sup>|"equals" &#124; "contains"|Davis event name must equal or contain the string provided. |
|name<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| |

### DavisEventTriggerConfig

| Name | Type |
| --- | --- |
|type<sup>*required</sup>|"davis-event"| 
|value<sup>*required</sup>|<a href="#daviseventconfig">DavisEventConfig</a>|

### DavisProblemCategories

| Name | Type |
| --- | --- |
|availability|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)| 
|custom|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)| 
|error|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)| 
|info|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)| 
|monitoringUnavailable|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)| 
|resource|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)| 
|slowdown|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)|

### DavisProblemConfig

| Name | Type | Description |
| --- | --- | --- |
|categories<sup>*required</sup>|<a href="#davisproblemcategories" target="_blank" rel="noopener noreferrer">DavisProblemCategories</a>| |
|customFilter|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Additional DQL matcher expression to further filter events to match. |
|entityTags|<a href="#entitytags">EntityTags</a>|Entity tags to match by key and (optional) values. For example &#123;&quot;foo&quot;: [], &quot;bar&quot;: [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]} |
|entityTagsMatch|"all" &#124; "any"|Event must match all or any of the entity tags. |
|onProblemClose|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)|Trigger on Davis problem open only or also on close. <i>default:</i> <code>false</code>|

### DavisProblemTriggerConfig

| Name | Type |
| --- | --- |
|type<sup>*required</sup>|"davis-problem"| 
|value<sup>*required</sup>|<a href="#davisproblemconfig" target="_blank" rel="noopener noreferrer">DavisProblemConfig</a>|

### EntityTags

Entity tags to match by key and (optional) values. For example \{&quot;foo&quot;: [], &quot;bar&quot;: [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]}

**type**: Record&lt;string, string | string[] | undefined&gt;

### Error

| Name | Type |
| --- | --- |
|code<sup>*required</sup>|[number](https://developer.mozilla.org/en-US/docs/Glossary/Number)| 
|details|<a href="#errordetails">ErrorDetails</a>| 
|message<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|

### ErrorDetails

**type**: Record&lt;string, any&gt;

### ErrorEnvelope

| Name | Type |
| --- | --- |
|error<sup>*required</sup>|<a href="#error" target="_blank" rel="noopener noreferrer">Error</a>|

### EventQuery

| Name | Type | Description |
| --- | --- | --- |
|eventType|"events" &#124; "bizevents" &#124; "dt.system.events"|Grail event type. |
|query<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|DQL matcher expression defining which events to match. |

### EventQueryTriggerConfig

| Name | Type |
| --- | --- |
|type<sup>*required</sup>|"event"| 
|value<sup>*required</sup>|<a href="#eventquery">EventQuery</a>|

### ModificationInfo

| Name | Type |
| --- | --- |
|createdBy<sup>*required</sup>|null &#124; [string](https://developer.mozilla.org/en-US/docs/Glossary/String)| 
|createdTime<sup>*required</sup>|Date| 
|lastModifiedBy<sup>*required</sup>|null &#124; [string](https://developer.mozilla.org/en-US/docs/Glossary/String)| 
|lastModifiedTime<sup>*required</sup>|Date|

### PaginatedSelfNotificationList

| Name | Type |
| --- | --- |
|count<sup>*required</sup>|[number](https://developer.mozilla.org/en-US/docs/Glossary/Number)| 
|results<sup>*required</sup>|Array&lt;<a href="#selfnotification" target="_blank" rel="noopener noreferrer">SelfNotification</a>&gt;|

### SelfNotification

| Name | Type | Description |
| --- | --- | --- |
|appId|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|App id for registered notification. Optional, by default automatically inferred from the request. Only relevant for manual testing purposes via swagger. |
|id<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| |
|input|<a href="#selfnotificationinput">SelfNotificationInput</a>|SelfNotificationInput object consisting of subject and content. Supports automation expressions https://dt-url.net/workflows-expression-reference and markdown syntax. A template provided with an app (&#123;notification_type}.notification-template.json) will take precedence over the input provided here. |
|modificationInfo<sup>*required</sup>|<a href="#modificationinfo" target="_blank" rel="noopener noreferrer">ModificationInfo</a>| |
|notificationType<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|String that defines the type of a notification in context of an app. Allows to differentiate between multiple types of notifications in context of one app. |
|owner<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| |
|resourceId<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Unique identifier of resource to notify on. Used to determine if there is a notification registered for a resource in context of the app and notification type for a user. |
|title|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| |
|triggerConfiguration<sup>*required</sup>|EventTriggerConfig| |

### SelfNotificationCreate

| Name | Type | Description |
| --- | --- | --- |
|appId|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|App id for registered notification. Optional, by default automatically inferred from the request. Only relevant for manual testing purposes via swagger. |
|id|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| |
|input|<a href="#selfnotificationinput">SelfNotificationInput</a>|SelfNotificationInput object consisting of subject and content. Supports automation expressions https://dt-url.net/workflows-expression-reference and markdown syntax. A template provided with an app (&#123;notification_type}.notification-template.json) will take precedence over the input provided here. |
|notificationType<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|String that defines the type of a notification in context of an app. Allows to differentiate between multiple types of notifications in context of one app. |
|resourceId<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Unique identifier of resource to notify on. Used to determine if there is a notification registered for a resource in context of the app and notification type for a user. |
|title|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| |
|triggerConfiguration<sup>*required</sup>|EventTriggerConfig| |

### SelfNotificationInput

| Name | Type |
| --- | --- |
|content|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| 
|subject|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|

### SelfNotificationUpdate

| Name | Type | Description |
| --- | --- | --- |
|appId|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|App id for registered notification. Optional, by default automatically inferred from the request. Only relevant for manual testing purposes via swagger. |
|input|<a href="#selfnotificationinput" target="_blank" rel="noopener noreferrer">SelfNotificationInput</a>|SelfNotificationInput object consisting of subject and content. Supports automation expressions https://dt-url.net/workflows-expression-reference and markdown syntax. A template provided with an app (&#123;notification_type}.notification-template.json) will take precedence over the input provided here. |
|notificationType|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|String that defines the type of a notification in context of an app. Allows to differentiate between multiple types of notifications in context of one app. |
|resourceId|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Unique identifier of resource to notify on. Used to determine if there is a notification registered for a resource in context of the app and notification type for a user. |
|title|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| |
|triggerConfiguration<sup>*required</sup>|EventTriggerConfig| |

## Enums

<a name="daviseventnamematch"></a>
### DavisEventNameMatch

<div class="padding-left--md">

Davis event name must equal or contain the string provided.

#### Enum keys

<div class="padding-left--md">

`Contains` | `Equals`

</div>


</div>

<a name="daviseventtriggerconfigtype"></a>
### DavisEventTriggerConfigType

<div class="padding-left--md">



#### Enum keys

<div class="padding-left--md">

`DavisEvent`

</div>


</div>

<a name="davisproblemtriggerconfigtype"></a>
### DavisProblemTriggerConfigType

<div class="padding-left--md">



#### Enum keys

<div class="padding-left--md">

`DavisProblem`

</div>


</div>

<a name="entitytagsmatch"></a>
### EntityTagsMatch

<div class="padding-left--md">

Event must match all or any of the entity tags.

#### Enum keys

<div class="padding-left--md">

`All` | `Any`

</div>


</div>

<a name="eventquerytriggerconfigtype"></a>
### EventQueryTriggerConfigType

<div class="padding-left--md">



#### Enum keys

<div class="padding-left--md">

`Event`

</div>


</div>

<a name="eventtype"></a>
### EventType

<div class="padding-left--md">

Grail event type.

#### Enum keys

<div class="padding-left--md">

`Bizevents` | `DtSystemEvents` | `Events`

</div>


</div>
