import { EventTriggerConfig } from './event-trigger-config';
import { ModificationInfo } from './modification-info';
import { SelfNotificationInput } from './self-notification-input';
export interface SelfNotification {
    id: string;
    title?: string;
    /**
     * Unique identifier of resource to notify on. Used to determine if there is a notification registered for a resource in context of the app and notification type for a user.
     */
    resourceId: string;
    /**
     * String that defines the type of a notification in context of an app. Allows to differentiate between multiple types of notifications in context of one app.
     */
    notificationType: string;
    triggerConfiguration: EventTriggerConfig;
    modificationInfo: ModificationInfo;
    /**
     * SelfNotificationInput object consisting of subject and content. Supports automation expressions https://dt-url.net/workflows-expression-reference and markdown syntax. A template provided with an app ({notification_type}.notification-template.json) will take precedence over the input provided here.
     */
    input?: SelfNotificationInput;
    /**
     * App id for registered notification. Optional, by default automatically inferred from the request. Only relevant for manual testing purposes via swagger.
     */
    appId?: string;
    owner: string;
}
